@@ -44,25 +44,30 @@
 //! implemented the concept of "proxy" types. Proxy types are a reference-like
 //! indirection between the user and the internal memory representation.
 
-use crate::RepeatedMut;
 use crate::__internal::Private;
-use crate::repeated::ProxiedInRepeated;
 use std::fmt::Debug;
 
 /// A type that can be accessed through a reference-like proxy.
 ///
-/// An instance of a `Proxied` can be accessed
-/// immutably via `Proxied::View` and mutably via `Proxied::Mut`.
+/// An instance of a `Proxied` can be accessed immutably via `Proxied::View`.
 ///
 /// All Protobuf field types implement `Proxied`.
-pub trait Proxied {
+pub trait Proxied: Sized {
     /// The proxy type that provides shared access to a `T`, like a `&'msg T`.
     ///
     /// Most code should use the type alias [`View`].
-    type View<'msg>: ViewProxy<'msg, Proxied = Self> + Copy + Send + SettableValue<Self>
+    type View<'msg>: ViewProxy<'msg, Proxied = Self> + Copy + Send
     where
         Self: 'msg;
+}
 
+/// A type that can be be accessed through a reference-like proxy.
+///
+/// An instance of a `MutProxied` can be accessed mutably via `MutProxied::Mut`
+/// and immutably via `MutProxied::View`.
+///
+/// `MutProxied` is implemented by message, map and repeated field types.
+pub trait MutProxied: Proxied {
     /// The proxy type that provides exclusive mutable access to a `T`, like a
     /// `&'msg mut T`.
     ///
@@ -83,7 +88,7 @@ pub type View<'msg, T> = <T as Proxied>::View<'msg>;
 ///
 /// This is more concise than fully spelling the associated type.
 #[allow(dead_code)]
-pub type Mut<'msg, T> = <T as Proxied>::Mut<'msg>;
+pub type Mut<'msg, T> = <T as MutProxied>::Mut<'msg>;
 
 /// Declares conversion operations common to all views.
 ///
@@ -127,7 +132,7 @@ pub trait ViewProxy<'msg>: 'msg + Sync + Unpin + Sized + Debug {
     ///     y: View<'b, T>,
     /// ) -> [View<'b, T>; 2]
     /// where
-    ///     T: Proxied,
+    ///     T: MutProxied,
     ///     'a: 'b,
     /// {
     ///     // `[x, y]` fails to compile because `'a` is not the same as `'b` and the `View`
@@ -147,7 +152,10 @@ pub trait ViewProxy<'msg>: 'msg + Sync + Unpin + Sized + Debug {
 ///
 /// This trait is intentionally made non-object-safe to prevent a potential
 /// future incompatible change.
-pub trait MutProxy<'msg>: ViewProxy<'msg> {
+pub trait MutProxy<'msg>: ViewProxy<'msg>
+where
+    Self::Proxied: MutProxied,
+{
     /// Gets an immutable view of this field. This is shorthand for `as_view`.
     ///
     /// This provides a shorter lifetime than `into_view` but can also be called
@@ -157,13 +165,6 @@ pub trait MutProxy<'msg>: ViewProxy<'msg> {
         self.as_view()
     }
 
-    /// Sets this field to the given `val`.
-    ///
-    /// Any borrowed data from `val` will be cloned.
-    fn set(&mut self, val: impl SettableValue<Self::Proxied>) {
-        val.set_on(Private, self.as_mut())
-    }
-
     /// Converts a borrow into a `Mut` with the lifetime of that borrow.
     ///
     /// This function enables calling multiple methods consuming `self`, for
@@ -206,90 +207,23 @@ pub trait MutProxy<'msg>: ViewProxy<'msg> {
         'msg: 'shorter;
 }
 
-// TODO: move this to `optional.rs` as it's only used for optionals
-/// `Proxied` types that can be optionally set or unset.
+/// A value to `Proxied`-value conversion that consumes the input value.
 ///
-/// All scalar and message types implement `ProxiedWithPresence`, while repeated
-/// types don't.
-pub trait ProxiedWithPresence: Proxied {
-    /// The data necessary to store a present field mutator proxying `Self`.
-    /// This is the contents of `PresentField<'msg, Self>`.
-    type PresentMutData<'msg>: MutProxy<'msg, Proxied = Self>;
-
-    /// The data necessary to store an absent field mutator proxying `Self`.
-    /// This is the contents of `AbsentField<'msg, Self>`.
-    type AbsentMutData<'msg>: ViewProxy<'msg, Proxied = Self>;
-
-    /// Clears a present field.
-    fn clear_present_field(present_mutator: Self::PresentMutData<'_>) -> Self::AbsentMutData<'_>;
-
-    /// Sets an absent field to its default value.
-    ///
-    /// This can be more efficient than setting with a default value, e.g.
-    /// a default submessage could share resources with the parent message.
-    fn set_absent_to_default(absent_mutator: Self::AbsentMutData<'_>) -> Self::PresentMutData<'_>;
-}
-
-/// Values that can be used to set a field of `T`.
-pub trait SettableValue<T>: Sized
-where
-    T: Proxied + ?Sized,
-{
-    /// Consumes `self` to set the given mutator to the value of `self`.
-    #[doc(hidden)]
-    fn set_on<'msg>(self, _private: Private, mutator: Mut<'msg, T>)
-    where
-        T: 'msg;
-
-    /// Consumes `self` and `absent_mutator` to set the given empty field to
-    /// the value of `self`.
-    #[doc(hidden)]
-    fn set_on_absent(
-        self,
-        _private: Private,
-        absent_mutator: T::AbsentMutData<'_>,
-    ) -> T::PresentMutData<'_>
-    where
-        T: ProxiedWithPresence,
-    {
-        let mut present = T::set_absent_to_default(absent_mutator);
-        self.set_on(Private, present.as_mut());
-        present
-    }
-
-    /// Consumes `self` and `present_mutator` to set the given present field
-    /// to the value of `self`.
-    #[doc(hidden)]
-    fn set_on_present(self, _private: Private, mut present_mutator: T::PresentMutData<'_>)
-    where
-        T: ProxiedWithPresence,
-    {
-        self.set_on(Private, present_mutator.as_mut())
-    }
-
-    /// Consumes `self` and `repeated_mutator` to set the value at the
-    /// given index to the value of `self`.
-    ///
-    /// # Safety
-    /// `index` must be less than `repeated_mutator.len()`
-    #[doc(hidden)]
-    unsafe fn set_on_repeated_unchecked(
-        self,
-        _private: Private,
-        mut _repeated_mutator: RepeatedMut<T>,
-        _index: usize,
-    ) where
-        T: ProxiedInRepeated,
-    {
-        unimplemented!()
-    }
+/// All setter functions accept types that implement `IntoProxied`. The purpose
+/// of `IntoProxied` is to allow setting arbitrary values on Protobuf fields
+/// with the minimal number of copies.
+///
+/// This trait must not be implemented on types outside the Protobuf codegen and
+/// runtime. We expect it to change in backwards incompatible ways in the
+/// future.
+pub trait IntoProxied<T: Proxied> {
+    fn into_proxied(self, _private: Private) -> T;
 }
 
 #[cfg(test)]
 mod tests {
     use super::*;
     use googletest::prelude::*;
-    use std::borrow::Cow;
 
     #[derive(Debug, Default, PartialEq)]
     struct MyProxied {
@@ -308,6 +242,9 @@ mod tests {
 
     impl Proxied for MyProxied {
         type View<'msg> = MyProxiedView<'msg>;
+    }
+
+    impl MutProxied for MyProxied {
         type Mut<'msg> = MyProxiedMut<'msg>;
     }
 
@@ -369,45 +306,6 @@ mod tests {
         }
     }
 
-    impl SettableValue<MyProxied> for MyProxiedView<'_> {
-        fn set_on<'msg>(self, _private: Private, mutator: Mut<'msg, MyProxied>)
-        where
-            MyProxied: 'msg,
-        {
-            mutator.my_proxied_ref.val = self.my_proxied_ref.val.clone();
-        }
-    }
-
-    impl SettableValue<MyProxied> for String {
-        fn set_on<'msg>(self, _private: Private, mutator: Mut<'msg, MyProxied>)
-        where
-            MyProxied: 'msg,
-        {
-            mutator.my_proxied_ref.val = self;
-        }
-    }
-
-    impl SettableValue<MyProxied> for &'_ str {
-        fn set_on<'msg>(self, _private: Private, mutator: Mut<'msg, MyProxied>)
-        where
-            MyProxied: 'msg,
-        {
-            mutator.my_proxied_ref.val.replace_range(.., self);
-        }
-    }
-
-    impl SettableValue<MyProxied> for Cow<'_, str> {
-        fn set_on<'msg>(self, _private: Private, mutator: Mut<'msg, MyProxied>)
-        where
-            MyProxied: 'msg,
-        {
-            match self {
-                Cow::Owned(x) => <String as SettableValue<MyProxied>>::set_on(x, Private, mutator),
-                Cow::Borrowed(x) => <&str as SettableValue<MyProxied>>::set_on(x, Private, mutator),
-            }
-        }
-    }
-
     #[test]
     fn test_as_view() {
         let my_proxied = MyProxied { val: "Hello World".to_string() };
@@ -417,18 +315,6 @@ mod tests {
         assert_that!(my_view.val(), eq(&my_proxied.val));
     }
 
-    #[test]
-    fn test_as_mut() {
-        let mut my_proxied = MyProxied { val: "Hello World".to_string() };
-
-        let mut my_mut = my_proxied.as_mut();
-        my_mut.set("Hello indeed".to_string());
-
-        let val_after_set = my_mut.as_view().val().to_string();
-        assert_that!(my_proxied.val, eq(val_after_set));
-        assert_that!(my_proxied.val, eq("Hello indeed"));
-    }
-
     fn reborrow_mut_into_view<'msg>(x: Mut<'msg, MyProxied>) -> View<'msg, MyProxied> {
         // x.as_view() fails to compile with:
         //   `ERROR: attempt to return function-local borrowed content`
@@ -460,7 +346,7 @@ mod tests {
         y: &'b View<'a, T>,
     ) -> [View<'b, T>; 2]
     where
-        T: Proxied,
+        T: MutProxied,
         'a: 'b,
     {
         // `[x, y]` fails to compile because `'a` is not the same as `'b` and the `View`
@@ -509,7 +395,7 @@ mod tests {
 
     fn reborrow_generic_mut_into_view<'a, 'b, T>(x: Mut<'a, T>, y: View<'b, T>) -> [View<'b, T>; 2]
     where
-        T: Proxied,
+        T: MutProxied,
         'a: 'b,
     {
         [x.into_view(), y]
@@ -529,7 +415,7 @@ mod tests {
 
     fn reborrow_generic_mut_into_mut<'a, 'b, T>(x: Mut<'a, T>, y: Mut<'b, T>) -> [Mut<'b, T>; 2]
     where
-        T: Proxied,
+        T: MutProxied,
         'a: 'b,
     {
         // `[x, y]` fails to compile because `'a` is not the same as `'b` and the `Mut`
@@ -552,17 +438,4 @@ mod tests {
             reborrow_generic_mut_into_mut::<MyProxied>(my_mut, other_mut);
         }
     }
-
-    #[test]
-    fn test_set() {
-        let mut my_proxied = MyProxied::default();
-        my_proxied.as_mut().set("hello");
-        assert_that!(my_proxied.as_view().val(), eq("hello"));
-
-        my_proxied.as_mut().set(String::from("hello2"));
-        assert_that!(my_proxied.as_view().val(), eq("hello2"));
-
-        my_proxied.as_mut().set(Cow::Borrowed("hello3"));
-        assert_that!(my_proxied.as_view().val(), eq("hello3"));
-    }
 }
